@@ -7,7 +7,7 @@ from typing import Union
 import iribaker
 from rdflib import Graph
 from rdflib.namespace import DC, DCTERMS, RDF, XSD
-from rdflib.term import Literal, URIRef
+from rdflib.term import IdentifiedNode, Literal, URIRef
 
 from .const import (
     ITSRDF,
@@ -32,6 +32,14 @@ class NifSentence:
     pass
 
 
+class NifParagraph:
+    pass
+
+
+class NifPage:
+    pass
+
+
 class NifPhrase:
     pass
 
@@ -66,8 +74,7 @@ class NifBase(object):
 
     def set_uri(self, uri: Union[URIRef, str] = None):
         """
-        Sets the uri of the object.
-        If the uri is a string then it is converted to an iri.
+        Sets the uri of the object. If the uri is a string then it is converted to an iri.
         """
         if isinstance(uri, str):
             self._uri = URIRef(iribaker.to_iri(uri))
@@ -232,9 +239,8 @@ class NifString(NifBase):
 
     def set_beginIndex(self, beginIndex: Union[Literal, int] = None):
         """
-        Sets the start of the index of the string.
-        The type of beginIndex can be a `Literal` or an `int`.
-        If the type is an `int` then it is converted to a Literal.
+        Sets the start of the index of the string. The type of beginIndex can be a `Literal` or
+        an `int`. If the type is an `int` then it is converted to a Literal.
         """
         if isinstance(beginIndex, int):
             self._beginIndex = Literal(beginIndex, datatype=XSD.nonNegativeInteger)
@@ -243,9 +249,8 @@ class NifString(NifBase):
 
     def set_endIndex(self, endIndex: Union[Literal, int] = None):
         """
-        Sets the end of the index of the string.
-        The type of endIndex can be a `Literal` or an `int`.
-        If the type is an `int` then it is converted to a Literal.
+        Sets the end of the index of the string. The type of endIndex can be a `Literal` or
+        an `int`. If the type is an `int` then it is converted to a Literal.
         """
         if isinstance(endIndex, int):
             self._endIndex = Literal(endIndex, datatype=XSD.nonNegativeInteger)
@@ -254,9 +259,7 @@ class NifString(NifBase):
 
     def set_referenceContext(self, referenceContext: NifContext = None):
         """
-        Sets the referenceContext of the object.
-        The anchorOf is set to the referenceContext string
-        with the beginIndex and endIndex.
+        Sets the referenceContext of the object. The anchorOf is set to the referenceContext string with the beginIndex and endIndex
         """
         if referenceContext is not None:
             if referenceContext.isString is not None:
@@ -266,9 +269,7 @@ class NifString(NifBase):
 
     def set_anchorOf(self, anchorOf: str = None):
         """
-        Sets the anchorOf of the object.
-        The anchorOf should be consistent with the string in
-        the referenceContext.
+        Sets the anchorOf of the object. The anchorOf should be consistent with the string in the referenceContext.
         """
         if isinstance(anchorOf, str):
             self._anchorOf = Literal(anchorOf, datatype=XSD.string)
@@ -1168,11 +1169,9 @@ class NifSentence(NifStructure):
                 s += f"  nextSentence : {repr(self.nextSentence.anchorOf)}\n"
         if self.previousSentence is not None:
             if len(self.previousSentence.anchorOf) > 100:
-                ps = repr(self.previousSentence.anchorOf[0:100])
-                s += f"  previousSentence : {ps}... \n"
+                s += f"  previousSentence : {repr(self.previousSentence.anchorOf[0:100])}... \n"
             else:
-                ps = repr(self.previousSentence.anchorOf)
-                s += f"  previousSentence : {ps}\n"
+                s += f"  previousSentence : {repr(self.previousSentence.anchorOf)}\n"
         if self.firstWord is not None:
             s += f'  firstWord : "{self.firstWord.anchorOf}"\n'
         if self.lastWord is not None:
@@ -1575,14 +1574,11 @@ class NifWord(NifStructure):
         if self.lemma is not None:
             s += f'  lemma : "{self.lemma}"\n'
         if self.pos is not None and self.pos != []:
-            pos = ", ".join([str(m).replace(OLIA, "olia:") for m in self.pos])
-            s += f'  pos : {pos}\n'
+            s += f'  pos : {", ".join([str(m).replace(OLIA, "olia:") for m in self.pos])}\n'
         if self.morphofeats is not None and self.morphofeats != []:
-            mf = ", ".join([str(m).replace(OLIA, "olia:") for m in self.morphofeats])
-            s += f'  morphofeats : {mf}\n'
+            s += f'  morphofeats : {", ".join([str(m).replace(OLIA, "olia:") for m in self.morphofeats])}\n'
         if self.dependency is not None and self.dependency != []:
-            dep = ", ".join([dep.uri for dep in self.dependency])
-            s += f'  dependency : {dep}\n'
+            s += f'  dependency : {", ".join([dep.uri for dep in self.dependency])}\n'  # [str(dep.uri) for dep in self.dependency]
         if self.dependencyRelationType is not None:
             s += f"  dependencyRelationtype : {self.dependencyRelationType}\n"
         return s
